@@ -326,6 +326,9 @@ class Resource(object):
     def delete(self):
         self.http_client.delete(self.uri)
 
+    def unstore(self):
+        self.delete()
+
 
 def uri_discovery(resource):
     uri = resource.RESOURCE['collection']
@@ -865,6 +868,22 @@ class Marketplace(Resource):
             meta=meta,
         ).save()
 
+    @staticmethod
+    def create_customer(**kwargs):
+        """
+        Creates a Customer under the marketplace associated with the current
+        API key used for this request.
+
+        :rtype: Customer
+        :raises: balanced.exc.HTTPError
+
+            Check the `status_code` and `category_code` properties of the
+            exception.
+
+        """
+        kwargs['resides_under_marketplace'] = True
+        return Customer(**kwargs).save()
+
     @classproperty
     @cached_per_api_key()
     def my_marketplace(cls):
@@ -935,6 +954,23 @@ class Credit(Resource):
     __metaclass__ = resource_base(collection='credits',
                                   resides_under_marketplace=False)
 
+    def reverse(self, amount=None, description=None, meta=None):
+        """
+        Reverse a Credit.  If no amount is specified it will reverse the entire
+        amount of the Credit, you may create many Reversals up to the sum of the
+        total of the original Credit amount.
+
+        :rtype: Reversal
+        """
+        meta = meta or {}
+        return Reversal(
+            uri=self.reversals_uri,
+            credits_uri=self.uri,
+            amount=amount,
+            description=description,
+            meta=meta,
+        ).save()
+
 
 class Refund(Resource):
     """
@@ -945,6 +981,14 @@ class Refund(Resource):
     """
     __metaclass__ = resource_base(collection='refunds')
 
+class Reversal(Resource):
+    """
+    A Reverse represents a reversal of funds from a Credit. A Credit can have
+    many Reverses associated with it up to the total amount of the original
+    Credit. Funds are returned to your Marketplace's Merchant Account
+    proportional to the amount of the Refund.
+    """
+    __metaclass__ = resource_base(collection='reversals')
 
 class Hold(Resource):
     """
@@ -976,7 +1020,8 @@ class Hold(Resource):
 
         :rtype: Debit
         """
-        return self.account.debit(hold_uri=self.uri, **kwargs)
+        participant = getattr(self, 'account', None) or self.customer
+        return participant.debit(hold_uri=self.uri, **kwargs)
 
 
 class APIKey(Resource):
@@ -1314,6 +1359,8 @@ class Customer(Resource):
 
     @property
     def active_bank_account(self):
+        if isinstance(self.destination, BankAccount):
+            return self.destination
         bank_accounts = self.bank_accounts.filter(is_valid=True,
                                                   sort='created_at,desc')
         return bank_accounts[0] if bank_accounts else None
